@@ -5,7 +5,6 @@ import os
 import aiofiles
 
 from gv_utils import datetime
-from gv_utils.enums import MessageKind
 
 DATA_PATH_STRUCT = '%Y/%m/%d/'
 
@@ -34,9 +33,6 @@ def _get_file_name(datadate: datetime, datafilestruct: str) -> str:
 
 
 def _get_datakind_dir(datakind: str) -> str:
-    sep = MessageKind.separator
-    splited = datakind.split(sep)
-    datakind = sep.join(splited[-1:] + splited[:-1])
     return datakind.upper()
 
 
