@@ -33,7 +33,7 @@ def encode_pandas(dataframe: pd.DataFrame) -> str:
     for col in dataframe.columns:
         try:
             if pdtypes.is_numeric_dtype(dataframe[col]):
-                dataframe[col] = dataframe[col].round().astype('int')
+                dataframe[col] = dataframe[col]
         except:
             pass
     dataframe.replace(MessageData.nan, '', inplace=True)
@@ -87,6 +87,7 @@ def decode_pandas(data: str) -> pd.DataFrame:
     dataframe = pd.read_csv(io.StringIO(data), sep=MessageData.csvseparator, index_col=0)
     dataframe.replace(MessageData.nan, np.NaN, inplace=True)
     dataframe.replace(str(MessageData.nan), np.NaN, inplace=True)
+    dataframe.dropna(inplace=True)
     try:
         dataframe.index = dataframe.index.astype('str')
     except:
